;; Generated package description from vundo.el  -*- no-byte-compile: t -*-
(define-package "vundo" "1.0.0.0.20220406.143052" "Visual undo tree" '((emacs "28.1")) :commit "377194b705b99b98068d18fda2c5ccdb94313e9c" :authors '(("Yuan Fu" . "casouri@gmail.com")) :maintainer '("Yuan Fu" . "casouri@gmail.com") :keywords '("undo" "text" "editing") :url "https://github.com/casouri/vundo")
